pub struct TheaterConnection {
pub address: SocketAddr,
/* private fields */
}Expand description
A client connection to a Theater server
This provides a thin wrapper around the TCP connection with simple send and receive methods that can be used with tokio::select!
Fields
address: SocketAddrServer address
Implementations
Sourceimpl TheaterConnection
impl TheaterConnection
Sourcepub fn new(address: SocketAddr) -> Self
pub fn new(address: SocketAddr) -> Self
Sourcepub async fn connect(&mut self) -> Result<()>
pub async fn connect(&mut self) -> Result<()>
Connect to the Theater server
Returns
Ok(())if the connection was successfulErr(...)if there was an error connecting
Sourcepub async fn send(&mut self, command: ManagementCommand) -> Result<()>
pub async fn send(&mut self, command: ManagementCommand) -> Result<()>
Sourcepub async fn receive(&mut self) -> Result<ManagementResponse>
pub async fn receive(&mut self) -> Result<ManagementResponse>
Receive a response from the server
This method will wait for the next response from the server. It can be used with tokio::select! to handle multiple operations.
Returns
Ok(response)if a response was receivedErr(...)if there was an error receiving the response
pub async fn send_and_receive( &mut self, command: ManagementCommand, ) -> Result<ManagementResponse>
Sourcepub fn is_connected(&self) -> bool
pub fn is_connected(&self) -> bool
Check if the connection is active
Returns
trueif the connection is activefalseif the connection is not active